|Build Status| |image1| |PyPi downloads| |PyPi version| |Docker pulls|

compose\_plantuml
=================

Generate Plantuml graphs from docker-compose files

Note that version 2 as well as the legacy version is supported.

Usage
-----

Via Python
~~~~~~~~~~

Install it via: ``pip3 install compose_plantuml``

After that use it like:
``compose_plantuml --link-graph docker-compose.yml``

Via Docker
~~~~~~~~~~

Use it like:
``cat docker-compose.yml | docker run -i funkwerk/compose_plantuml --link-graph``

Link Graph
----------

Link Graphs provide an overview over docker-compose services.

Consider the following docker-compose.yml

::

    version: '2'
    services:
      first:
        links:
          - second
      second: {}

When calling 'compose\_plantuml docker-compose.yml' it will generate the
following link graph:

::

    [first]
    [second]
    [first] --> [second]

Rendered it looks like:

Boundaries
----------

Boundaries visualize the external boundaries a system has.

Consider the following docker-compose.yml

::

    version: '2'
    services:
      service:
        ports:
          - 8080:80

When calling 'compose\_plantuml --boundaries docker-compose.yml' it will
generate the following plantuml:

::

    rectangle system {
      [service]
    }
    [service] --> 8080 : 80

Rendered it looks like:

Related Links
-------------

-  draw compose
-  https://github.com/Alexis-benoist/draw-compose
-  generates dot graphs from docker-compose files
-  currently just supports docker-compose version 1
-  does not read from stdin, so is not easy useable as docker container

.. |Build Status| image:: https://travis-ci.org/funkwerk/compose_plantuml.svg
   :target: https://travis-ci.org/funkwerk/compose_plantuml
.. |image1| image:: https://badge.imagelayers.io/funkwerk/compose_plantuml.svg
   :target: https://imagelayers.io/?images=funkwerk/compose_plantuml:latest
.. |PyPi downloads| image:: https://img.shields.io/pypi/dm/compose_plantuml.svg
   :target: https://pypi.python.org/pypi/compose_plantuml/
.. |PyPi version| image:: https://img.shields.io/pypi/v/compose_plantuml.svg
   :target: https://pypi.python.org/pypi/compose_plantuml/
.. |Docker pulls| image:: https://img.shields.io/docker/pulls/funkwerk/compose_plantuml.svg
   :target: https://hub.docker.com/r/funkwerk/compose_plantuml/
